import SwiftUI
import OrderedCollections

struct ActivitySamplesView: View {

    @EnvironmentObject
    var database: HealthDatabase

    let activity: WorkoutActivity

    @State var samples: [(type: Sample.DataType, samples: [Sample])] = []

    init(activity: WorkoutActivity) {
        self.activity = activity
    }

    var body: some View {
        List {
            ForEach(samples, id: \.0) { entry in
                NavigationLink {
                    SampleListView(type: entry.type, samples: entry.samples)
                } label: {
                    DetailRow(entry.type.description, value: entry.samples.count)
                }
            }
        }.onAppear(perform: load)
    }

    private func load() {
        Task {
            self.loadAsync()
        }
    }

    private func loadAsync() {
        do {
            let samples = try database.samples(for: activity)
            let ordered = samples
                .sorted(using: { $0.key.rawValue })
                .map { (type: $0, samples: $1) }
            DispatchQueue.main.async {
                self.samples = ordered
            }
        } catch {
            print("Failed to load samples: \(error)")
        }
    }
}

#Preview {
    ActivitySamplesView(activity: .mock1)
}
